# -*- coding: utf-8 -*-
#
# ** header v3.0
# This file is a part of the CaosDB Project.
#
# Copyright (c) 2020 IndiScale GmbH <www.indiscale.com>
# Copyright (c) 2020 Timm Fitschen <t.fitschen@indiscale.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# ** end header
import pytest

import caosdb as db
from caosdb.common.utils import xml2str


def setup_module():
    d = db.execute_query("FIND Test*")
    if len(d) > 0:
        d.delete()


def setup():
    setup_module()


def teardown():
    setup_module()


@pytest.mark.xfail(reason="""see pylib issue #31""")
def test_add_properties_with_wrong_role():
    p = db.Property(name="TestProperty1", datatype=db.TEXT).insert()
    rt = db.RecordType(name="TestRT1").add_property("TestProperty1").insert()

    wrong_role = db.Record(name="TestRT1").retrieve()
    right_role = db.RecordType(name="TestRT1").retrieve()
    rec = db.Record(name="fail").add_property(wrong_role)
    rec2 = db.Record(name="ok").add_property(right_role)

    assert wrong_role.get_property("TestProperty1") is not None
    assert str(wrong_role.get_property("TestProperty1")) == str(
        right_role.get_property("TestProperty1"))

    xml = rec2.to_xml()
    assert not xml.xpath("/Record/Property/Property")

    xml = rec.to_xml()
    # TODO this fails because the Record is treated differently than the
    # RecordType.
    assert not xml.xpath("/Record/Property/Property")
